# to run git subtree pull instead of generate constants
# add an argument (can be anything) after ./generate_consts.sh
# example: ./generate_consts.sh gen
# to run normally (no git subtree pull) just use ./generate_consts.sh

filename='pubspec.yaml'
readme='README.md'
changelog='CHANGELOG.md'
CONTENT=''
VERSION=$(git describe --long | awk '{split($0,a,"-"); print a[1] "." a[2] "." a[3]}' | awk '{split($0,a,"."); print a[1] "." a[2] "." a[3] + a[4] " " a[5]}')

update_in_readme()
{
    echo ''
    echo ''
    echo 'updating README version.......'
    echo ''
    echo ''
    while read line; do
    if [[ $line == capture_flutter_beta:* ]]; then
        echo 'LINE FOUND'
        sed -i "" "s/$1/$2/" $readme
        echo "new version number in README.md: $2"
        break
    fi

    done < $readme

    exit 1

    # add_new_changelog_item $2
}

which_version_number()
{   
    echo $2
    echo ''
    echo ''
    echo 'updating package version.......'
    echo ''
    echo ''

    IN=$2
    
    sed -i "" "s/$IN/$VERSION/" $filename
    echo "new version number: $VERSION"
    
    update_in_readme $IN $VERSION 
}

update_package_version()
{
    echo ''
    echo ''
    echo 'looking for version line...'
    echo ''
    echo ''
    while read line; do
    if [[ $line == version:* ]]; then
        echo 'LINE FOUND'
        which_version_number $line
        return
    fi

    done < $filename
}

generate_constants_pt_two()
{
    echo 'Generating Constants...'
    echo ''
    echo ''
    python3 constants/buildscripts/createErrors.py Dart constants/errors.json templates/errors_template.dart lib/classes/gen/errors.dart ble
    python3 constants/buildscripts/createDataSources.py Dart constants/dataSourceIds.json templates/datasources_template.dart lib/classes/gen/data_sources.dart ble
    python3 constants/buildscripts/createDeviceTypes.py Dart constants/deviceTypes.json templates/device_types_template.dart lib/classes/gen/device_types.dart ble
    python3 constants/buildscripts/createEventIds.py Dart constants/eventIDs.json templates/events_template.dart lib/classes/gen/event_ids.dart ble
    python3 constants/buildscripts/createPropertyIds.py Dart constants/propertyIDs.json templates/properties_template.dart lib/classes/gen/property_ids.dart ble
}

add_new_changelog_item()
{
    sed -i "" "8i\
    \
    ## [1.2.1] - 2022-02-24\
    ### Added\
    - ADD YOUR CHANGE HERE\
    " $changelog
}

version() 
{
    x=$(git describe --long | awk '{split($0,a,"-"); print a[1] "." a[2] "." a[3]}' | awk '{split($0,a,"."); print a[1] "." a[2] "." a[3] + a[4] " " a[5]}')
    update_package_version ${x}
}

init(){
    echo 'Do you want to get subtree or generate constants and update version files? (get/gen/version)'
    read INPUT
    new_input=`echo "$INPUT" | tr '[:upper:]' '[:lower:]'`
    if [ $new_input == "get" ]; then
        echo 'Getting Constants from Subtree...'
        echo ''
        echo ''
        git subtree pull --prefix constants git@git.socketmobile.com:scanning/captureconstants-universal.git master --squash
    elif [ $new_input == "gen" ]; then
        generate_constants_pt_two   
    elif [ $new_input == "version" ]; then
        version
    else 
        echo 'Invalid option.'
        init
    fi
}

# version

init